# Changelog

## [stormi-v0.1.0-beta.1](https://github.com/pinellolab/stormi/compare/stormi-v0.0.1...stormi-v0.1.0-beta.1) (2025-03-19)

### Features

* **stormi:** update entrypoint text ([a846e2e](https://github.com/pinellolab/stormi/commit/a846e2eaf9eba22a225ff573062b712c3932d234))
